#
# spec file for package hspec-discover
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hspec-discover
%bcond_with tests
Name:           %{pkg_name}
Version:        2.9.4
Release:        bp155.2.16
Summary:        Automatically discover and run Hspec tests
License:        MIT
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-meta-devel
BuildRequires:  ghc-mockery-devel
%endif

%description
Automatically discover and run Hspec tests

<http://hspec.github.io/hspec-discover.html>.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%autosetup

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license LICENSE
%{_bindir}/%{name}

%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files

%changelog
* Thu Dec  9 2021 Peter Simons <psimons@suse.com>
- Update hspec-discover to version 2.9.4.
  Upstream does not provide a change log file.
* Tue Nov 16 2021 psimons@suse.com
- Update hspec-discover to version 2.9.1.
  Upstream does not provide a change log file.
* Mon Nov 15 2021 psimons@suse.com
- Update hspec-discover to version 2.9.0.
  Upstream does not provide a change log file.
* Mon Nov  8 2021 psimons@suse.com
- Update hspec-discover to version 2.8.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Nov  7 2021 psimons@suse.com
- Update hspec-discover to version 2.8.4.
  Upstream does not provide a change log file.
* Fri Aug 13 2021 psimons@suse.com
- Update hspec-discover to version 2.8.3.
  Upstream does not provide a change log file.
* Sat May 15 2021 psimons@suse.com
- Update hspec-discover to version 2.8.2.
  Upstream does not provide a change log file.
* Wed May 12 2021 psimons@suse.com
- Update hspec-discover to version 2.8.1.
  Upstream does not provide a change log file.
* Tue May 11 2021 psimons@suse.com
- Update hspec-discover to version 2.8.0.
  Upstream does not provide a change log file.
* Thu Apr 15 2021 psimons@suse.com
- Update hspec-discover to version 2.7.10.
  Upstream does not provide a change log file.
* Mon Mar 22 2021 psimons@suse.com
- Update hspec-discover to version 2.7.9.
  Upstream does not provide a change log file.
* Mon Jan 18 2021 psimons@suse.com
- Update hspec-discover to version 2.7.8.
  Upstream does not provide a change log file.
* Mon Jan 18 2021 psimons@suse.com
- Update hspec-discover to version 2.7.7.
  Upstream does not provide a change log file.
* Fri Jan  8 2021 psimons@suse.com
- Update hspec-discover to version 2.7.6.
  Upstream does not provide a change log file.
* Mon Jan  4 2021 psimons@suse.com
- Update hspec-discover to version 2.7.5.
  Upstream does not provide a change log file.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Sep  4 2020 psimons@suse.com
- Update hspec-discover to version 2.7.4.
  Upstream does not provide a change log file.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Mar 30 2019 psimons@suse.com
- Update hspec-discover to version 2.7.1.
  Upstream does not provide a change log file.
* Fri Jan 18 2019 psimons@suse.com
- Update hspec-discover to version 2.7.0.
  Upstream does not provide a change log file.
* Tue Jan  1 2019 psimons@suse.com
- Update hspec-discover to version 2.6.1.
  Upstream does not provide a change log file.
* Sun Nov  4 2018 psimons@suse.com
- Update hspec-discover to version 2.6.0.
  Upstream does not provide a change log file.
* Wed Oct 10 2018 psimons@suse.com
- Update hspec-discover to version 2.5.8.
  Upstream does not provide a change log file.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update hspec-discover to version 2.5.5.
  Upstream does not provide a change log file.
* Fri Jul 13 2018 psimons@suse.com
- Update hspec-discover to version 2.5.4.
  Upstream does not provide a change log file.
* Mon May 14 2018 psimons@suse.com
- Update hspec-discover to version 2.5.0.
  No change log available from upstream.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 2.4.4.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 2.4.3 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 2.4.2 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 2.4.1 with cabal2obs.
* Tue Nov  1 2016 psimons@suse.com
- Update to version 2.2.4 with cabal2obs.
* Mon Jul 18 2016 psimons@suse.com
- Update to version 2.2.3 revision 0 with cabal2obs.
